@@ -56,25 +56,25 @@ KExportDialog::KExportDialog( TQWidget *parent, const char *name ) : TQDialog(pa
 	button->setText( "OK" ) ;
 	button->setFixedSize( 60, 25 ) ;
 	button->move( 100, 90 ) ;
-	connect( button, TQT_SIGNAL( clicked() ), this, TQT_SLOT( btnOKClicked() ) ) ;
+	connect( button, TQ_SIGNAL( clicked() ), this, TQ_SLOT( btnOKClicked() ) ) ;
 	
 	button = new TQPushButton( this ) ;
 	button->setText( "Cancel" ) ;
 	button->setFixedSize( 60, 25 ) ;
 	button->move( 200, 90 ) ;
-	connect( button, TQT_SIGNAL( clicked() ), this, TQT_SLOT( btnCancelClicked() ) ) ;
+	connect( button, TQ_SIGNAL( clicked() ), this, TQ_SLOT( btnCancelClicked() ) ) ;
 
 	button = new TQPushButton( this ) ;
 	button->setText( "..." ) ;
 	button->setFixedSize( 25, 20 ) ;
 	button->move( 270, 10 ) ;
-	connect( button, TQT_SIGNAL( clicked() ), this, TQT_SLOT( showFileDialog() ) )  ;
+	connect( button, TQ_SIGNAL( clicked() ), this, TQ_SLOT( showFileDialog() ) )  ;
 	
 	button = new TQPushButton( this ) ;
 	button->setText( "..." ) ;
 	button->setFixedSize( 25, 20 ) ;
 	button->move( 270, 35 ) ;
-	connect( button, TQT_SIGNAL( clicked() ), this, TQT_SLOT( showDirDialog() )  ) ;
+	connect( button, TQ_SIGNAL( clicked() ), this, TQ_SLOT( showDirDialog() )  ) ;
 		
 	setFixedSize( 340, 130 ) ;
 	setCaption( "Export to VHDL" ) ;
