@@ -35,7 +35,7 @@
 
 class KJTAGDialog : public TQDialog
 {	
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 	    KJTAGDialog(TQWidget *parent);
