@@ -150,7 +150,7 @@ KPicoSim::KPicoSim() : TDEMainWindow( 0, "KPicoSim" )
 
 	m_messages->addColumn( "Line" ) ;
 	m_messages->addColumn( "Description" ) ;
-	m_messages->setSorting( -1, FALSE ) ;
+	m_messages->setSorting( -1, false ) ;
 	m_simulator->setMessageList( m_messages ) ;
 
 	m_simulationMode = false ;
@@ -299,7 +299,7 @@ void KPicoSim::fileExportHEX()
 		   										     this,
   												     "Export HEX" ) ;
 	if ( filename != "" && compile() ) {
-		m_simulator->exportHEX( filename.ascii(), FALSE ) ;
+		m_simulator->exportHEX( filename.ascii(), false ) ;
 	}
 }
 
@@ -311,7 +311,7 @@ void KPicoSim::fileExportMEM()
 		   										     this,
   												     "Export MEM" ) ;
 	if ( filename != "" && compile() ) {
-		m_simulator->exportHEX( filename.ascii(), TRUE ) ;
+		m_simulator->exportHEX( filename.ascii(), true ) ;
 	}
 }
 
@@ -516,17 +516,17 @@ bool KPicoSim::compile()
 	m_messages->clear() ;
 	
 	if ( !m_editor->save() ) 
-		return FALSE;
+		return false;
 
 	appendMessage( "File '" + m_editor->getFilename() + "' saved" ) ;
 	m_simulator->setFilename( m_editor->getFilename().ascii() ) ;
 		
-	if ( m_simulator->compile() == TRUE ) {
+	if ( m_simulator->compile() == true ) {
 		appendMessage( "***Compile Success*** " ) ;
-		return TRUE ;
+		return true ;
 	} else {
 		appendMessage( "***Compile Failed*** " ) ;
-		return FALSE ;
+		return false ;
 	}
 }
 
@@ -543,7 +543,7 @@ void KPicoSim::startSim()
 
 			m_simulator->reset() ;
 			m_nrInstructions = 0 ;
-			m_simulationMode = TRUE ;
+			m_simulationMode = true ;
 		}
 	} else {
 		if ( m_simulator->isRunning() )
@@ -553,7 +553,7 @@ void KPicoSim::startSim()
 		m_debugMenu->changeItem( START_SIM_ID, ldr->loadIcon( "system-run", TDEIcon::Small ), "Start Debug" ) ;
 		m_debugBar->setButton( START_SIM_ID, false ) ;
 		m_editor->clearExecutionMarker() ;
-		m_simulationMode = FALSE ;
+		m_simulationMode = false ;
 	}
 
 	if ( m_simulationMode ) {
