@@ -36,7 +36,7 @@
 
 class KSimulator : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
     	KSimulator(TQObject *parent = 0, const char *name = 0);
